@@ -51,28 +51,16 @@ class FeiShuPlugin(NotificationPlugin):
             return
 
         webhook_url = self.get_option('webhook_url', group.project)
-
-        title = u"{}项目发生报错".format(event.project.slug)
-        event_url = u"{}events/{}/".format(group.get_absolute_url(), event.event_id)
-
-        # t = "group: \n"
-        # for i in dir(group): 
-        #     t = t + "{key}: {value} \n".format(
-        #         key = i,
-        #         value = group[i]
-        #     )
-
-        # t = t + "event: \n"
-
-        # for j in dir(event): 
-        #     t = t + "{key}: {value} \n".format(
-        #         key = j,
-        #         value = event[j]
-        #     )
+        project = event.group.project
+        title = u"New alert from {}".format(project.slug)
 
         data = {
             "title": title,
-            "text": event_url
+            "text": u"#### {title} \n > {message} [href]({url})".format(
+                title=title,
+                message=event.message,
+                url=u"{}events/{}/".format(group.get_absolute_url(), event.event_id),
+            )
         }
         requests.post(
             url=webhook_url,
